def punit():
           print("Punit modi")
           return

def mihir():
           print("Mihir Porwal")
           return

def romil():
           print("Romil Jain")
           return

def rohit():
           print("Rohit Jatt")
           return
